import "./handler";
import { SoftDeletableConfig } from "./common";
interface Type<T> {
    new (...args: any[]): T;
    prototype: T;
}
type EntityDecorator<Entity> = (type: Type<Entity>) => void;
export interface InferableSoftDeletableConfig<Entity, Field extends keyof Entity> extends SoftDeletableConfig<Entity, Field> {
    type: () => Type<Entity>;
}
/**
 * Mark an entity type as soft-deletable.
 * @see SoftDeletionEventSubscriber
 */
export declare function SoftDeletable<Entity, Field extends keyof Entity>(config: InferableSoftDeletableConfig<Entity, Field>): EntityDecorator<Entity>;
/**
 * Mark an entity type as soft-deletable.
 * @param type - Helper function for type inference.
 * @param field - Identifier field used to identify deleted entities.
 * @param value - Value to set to the identifier field in deletions.
 * @param valueInitial - Value to identify entities that is NOT soft-deleted. Defaults to `null`.
 * @see SoftDeletionEventSubscriber
 */
export declare function SoftDeletable<Entity, Field extends keyof Entity>(type: () => Type<Entity>, field: Field, value: () => Entity[Field], valueInitial?: Entity[Field]): EntityDecorator<Entity>;
export {};
//# sourceMappingURL=decorator.d.ts.map