"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.SoftDeleteHandler = void 0;
const core_1 = require("@mikro-orm/core");
const common_1 = require("./common");
/**
 * Intercept deletions of soft-deletable entities and perform updates instead.
 *
 * @see SoftDeletable
 * @see https://github.com/mikro-orm/mikro-orm/issues/1492#issuecomment-785394397
 */
class SoftDeleteHandler {
    static register(orm) {
        orm.em.getEventManager().registerSubscriber(new this());
    }
    async onFlush({ uow }) {
        uow
            .getChangeSets()
            .forEach((item) => {
            if (item.type === core_1.ChangeSetType.DELETE &&
                Reflect.hasMetadata(common_1.SOFT_DELETABLE, item.entity.constructor)) {
                const { field, value } = Reflect.getMetadata(common_1.SOFT_DELETABLE, item.entity.constructor);
                item.type = core_1.ChangeSetType.UPDATE;
                item.entity[field] = value();
                item.payload[field] = value();
                // Don't recompute here. Otherwise ManyToOne relation fields will be
                // set to `null` and cause a `NotNullConstraintViolationException`.
                // This only appear when using `cascade: [Cascade.ALL],
                // it will be fine to recompute here when using
                // `orphanRemoval: true`.
                // But because we can't catch the deletions caused by
                // `orphanRemoval`, we still chose `cascade: [Cascade.ALL],
                // uow.recomputeSingleChangeSet(item.entity);
            }
        });
    }
}
exports.SoftDeleteHandler = SoftDeleteHandler;
//# sourceMappingURL=handler.js.map